af436a53d2bb152a9385dbb9746e19258580a37c
larrym
  Fri Feb 18 13:33:17 2011 -0800
start => chromStart in parameter lists; fix bug in codonToPos (cdsEnd s/d be cdsStart)
diff --git src/hg/inc/genePred.h src/hg/inc/genePred.h
index 2066a11..f721cfd 100644
--- src/hg/inc/genePred.h
+++ src/hg/inc/genePred.h
@@ -278,26 +278,26 @@
 /* create a new gene with space for the specified number of exons allocated.
  * genePredGrow maybe used to expand this space if needed. */
 
 void genePredGrow(struct genePred *gp, unsigned *exonSpacePtr);
 /* Increase memory allocated to a psl to hold more exons.  exonSpacePtr
  * should point the the current maximum number of exons and will be
  * updated to with the new amount of space. */
 
 struct rbTree *genePredToRangeTree(struct genePred *gp, boolean cdsOnly);
 /* Convert genePred into a range tree. */
 
 void gpPartOutAsBed(struct genePred *gp, int start, int end, FILE *f, 
 	char *type, int id, int minSize);
 /* Write out part of gp as bed12. */
 
-boolean codonToPos(struct genePred *gp, unsigned num, int *start, int *end);
+boolean codonToPos(struct genePred *gp, unsigned num, int *chromStart, int *chromEnd);
 // map 1-based codon to genomic coordinates. If the codon crosses an exon junction, we return just the beginning (LHS) of the codon.
 // Returns true if we find the codon in given gene predition; start and end are set to appropriate three base region.
 
-boolean exonToPos(struct genePred *gp, unsigned num, int *start, int *end);
+boolean exonToPos(struct genePred *gp, unsigned num, int *chromStart, int *chromEnd);
 // map 1-based exon number to genomic coordinates.
 // Returns true if we find the exon in given gene predition; start and end are set to appropriate region.
 
 
 #endif /* GENEPRED_H */
@@ -278,26 +278,26 @@
 // map 1-based codon to genomic coordinates. If the codon crosses an exon junction, we return just the beginning (LHS) of the codon.
-// Returns true if we find the codon in given gene predition; start and end are set to appropriate three base region.
+// Returns true if we find the codon in given gene predition; chromStart and chromEnd are set to appropriate three base region.
 
@@ -278,26 +278,26 @@
 // map 1-based exon number to genomic coordinates.
-// Returns true if we find the exon in given gene predition; start and end are set to appropriate region.
+// Returns true if we find the exon in given gene predition; chromStart and chromEnd are set to appropriate region.
 
 